# Master localization string file: $Id$
direction: ltr
language_name: Čeština
more_options: Další možnosti
title_more_options: Zobrazit/Skrýt další možnosti ověření
all: Vše
normal_report: Normální zpráva
most_important: Nejdůležitější
no_warnings: Žádné varování
profile: Profil
no_special_profile: Žádný zvláštní profil
css1: CSS Úroveň 1
css2: CSS Úroveň 2
css21: CSS Úroveň 2.1
css3: CSS Úroveň 3
svg: SVG
svgbasic: SVG základní
svgtiny: SVG malý
mobile: Mobil
css3svg: CSS Úroveň 3 + SVG
ATSC_TV_profile: ATSC TV profil
TV_profile: TV profil
medium: Střední
aural: zvukový
braille: braillovo
embossed: vypouklý
handheld: do ruky
print: tisk
projection: projekce
screen: obrazovka
tty: TTY
tv: TV
presentation: prezentace
type: Typ
no_special_type: Automaticky
html_doc: HTML
css_doc: CSS
check: Zkontrolovat
W3C_CSS_validation_service: Validační služba W3C CSS
check_CSS: Zkontrolovat tabulky kaskádových stylů (CSS) a dokumenty  (X)HTML s tabulkami stylů.
by_URI: Podle URl
by_file_upload: Nahráním souboru
by_direct_input: Přímým vstupem
validate_by_URI: Ověřením URI
enter_uri: Zadejte URI dokumentu (HTML pouze s CSS nebo CSS), který chcete ověřit.
page_address: Adresa stránky k ověření
address: Adresa
submit_uri: Potvrďte URI pro ověření
validate_by_file_upload: Ověřit po nahrání souboru
choose_document: Vyberte dokument, který chcete ověřit
choose_local_file: Vyberte soubor k nahrání a ověření
local_CSS_file: Místní soubor CSS
submit_file: Potvrďte soubor k ověření
validate_by_input: Ověřte přímým vstupem
enter_CSS: Zadejte CSS, kterou chcete ověřit
submit_input: Potvrďte vstup pro ověření
note: Poznámka
note_xhtml_valid: Pokud chcete ověřit svůj CSS styl vložený do dokumentu (X)HTML měli byste nejprve zkontrolovat  <a href="https://validator.w3.org/">, že vámi použité (X)HTML je platné </a>
# Konec proměnných přidaných společně se stránkou šablony

W3C_validator_results:Validátor výsledků W3C CSS
# file_title: <!—poskytnuto uživatelem -->
CSS_validation_service: Validační služba CSS
jump_to: Přejít na
# errors_count: <!—vygenerovány v průběhu -->
errors: Chyby
# warnings_count <!—vygenerováno v průběhu -->
warnings: Varování
validated_CSS: Ověřené CSS
congrats: Blahopřejeme! Chyby nenalezeny!
# Věta definovaná\nproměnnými doc_validates_before_link a  n\doc_validates_after_link zní: \
# "Tento document ověřuje jako CSSXX!" kdy XX stanoví pro použitou verzi CSS \
#  Vzhledem k tomu, že je obsah odkazu verze CSS generovaného v průběhu, \
# je důležité definovat co bude před odkazem a co bude po něm 2 oddělenými \
# proměnnými, protože pozice odkazu ve větě je v různých jazycích proměnlivá
doc_validates_before_link: Tento dokument ověřuje jako 
doc_validates_after_link: !
no_errors_interoperable_msg: Abyste svým čtenářům ukázali, že se snažíte vytvořit vzájemně spolupracující webovou stránku, můžete tuto ikonu zobrazit na kterékoli stránce, která se ověřuje. Zde je XHTML, kterou můžete použít, abyste tuto ikonu přidali na svou webovou stránku:
valid_CSS: Ověřit CSS!
# <!—zavřít tag > místo /> při použití HTML<= 4.01 -->
no_errors_close_tags_msg: zavřít tag obrázku s &gt; místo /&gt; při použití HTML &lt;= 4.01
no_errors_dl_local_msg: Chcete-li můžete si stáhnout kopii tohoto obrázku, který se zobrazí na vašem místním webovém adresáři a změnit fragment XHTML na odkaz na váš obrázek než na ten na tomto serveru.
no_errors_create_link_msg: Chcete-li vytvořit odkaz na tuto stránku (tj. tento výsledek ověření ) znovuověření této stránky v budoucnosti nebo umožněte ostatním ověřit vaši stránku, URI je:
no_errors_forHTML_only_msg: pouze pro dokument HTML/XML
no_errors_bookmark_msg: Nebo stačí, když přidáte aktuální stránku do záložky nebo do oblíbených.
note_valide_html: Aby tabulka stylů CSS fungovala jak chcete, musí mít správnou syntaxi. To znamená, že byste měli použít <a href="https://validator.w3.org/">valid HTML</a>.
top: Nahoru
# hook_html_validator <!—vygenerováno v průběhu -->
not-css1-style: /* POZOR ! Toto není vlastnost CSS1! */
errors_sorry_msg: Litujeme! Našli jsme následující chyby
# errors_list: <!—vygenerováno v průběhu -->
# warnings_list: <!—vygenerováno  v průběhu -->
# rules_count: <!—vygenerováno v průběhu  -->
valid_CSS_info: Platná informace CSS
# charset: <!—vygenerováno v průběhu -->
# rules_list: <!—vygenerováno v průběhu -->
CSS_not_found: Tabulka stylů nenalezena
home: Domů
about: O
doc: Dokumentace
dl: Stáhnout
feedback: Feedback
credits: Kredity
home_title: Domácí stránka validační služby W3C CSS 
about_title: O této službě
doc_title: Dokumentace pro validační službu W3C CSS
dl_title: Stáhnout a nainstalovat validátor CSS
feedback_title: Jak poskytnout feedback ohledně této služby
credits_title: Kredity a potvrzení
W3C_quality_msg: Činnost zajištění kvality W3C vám přináší webové nástroje zdarma a mnohem více 
learn_more_msg: Dozvědět se více o tabulkách kaskádových stylů
support: Podpořte tento nástroj, staňte se
supporter: podporovatelem W3C
# Konec proměnných přidaných s rychlostí

# Definuje vaši vlastní chybu a varovné hlášení
content-type: text/html; charset=utf-8
content-language: cs
output-encoding-name: utf-8

# Můžete změnit úroveň varování takto (příklad) :
# warning.redefinition.level: 5
#  úroveň je číslo mezi 0 a 9 (všechny ostatní hodnoty jsou ignorovány)
warning.redefinition: Redefinice \u201C\u201C%s\u201D\u201D

# použito syntaktickým analyzátorem xml 
warning.style-inside-comment: Nevkládejte pravidla stylu do komentáře HTML, protože mohou být odstraněny zástupcem uživatele

# used by org.w3c.css.properties.Css1Style
warning.same-colors: Stejná barva pro \u201C\u201C%s\u201D\u201D a \u201C\u201C%s\u201D\u201D
warning.no-color: Nemáte žádnou sadu barev (nebo je barva nastavena na  průhlednou), ale nastavte si barvu pozadí. Ujistěte se, že řazení do kaskády barev ponechává text čitelným.
warning.no-background-color: Nemáte žádnou sadu barev (nebo je barva nastavena na průhlednou), ale nastavte si sadu bareve. Ujistěte se, že řazení do kaskády barev ponechává text čitelným.
#warning.color.mixed-capitalization: Přestože jsou názvy barev necitlivé na velká a malá písmena, doporučuje se používat různé styly psaní, aby názvy byly čitelnější: \u201C%s\u201D
warning.no-generic-family: \u201C%s\u201D: Jako poslední možnost vám doporučujeme generický soubor
warning.with-space: Názvy obsahující bílé znaky by měly být uvedeny. Je-li uvedení vynechané, jakékoli bílé znaky před a po  názvu jsou ignorovány a jakákoli sekvence znaků uvnitř názvu je převedena  do jedné mezery. 
warning.no-padding: Doporučuje se, abyste do oblasti doplnili barvu pozadí
warning.same-colors2: Stejné barvy pro barvu a barvu pozadí ve dvou kontextech \u201C%s\u201D a \u201C%s\u201D
warning.relative-absolute: Máte nějaké absolutní a relativní délky v \u201C%s\u201D. Toto není robustní tabulka stylů.
# used by org.w3c.css.properties.CssSelectors
warning.unknown-html: \u201C%s\u201D není prvek HTML
warning.html-inside:prvek HTML nemůže být v jiném prvku
warning.body-inside: TĚLO prvku nemůže být v jiném prvku vyjma HTML
warning.pseudo-classes: Ukotvení pseudo-třídy \u201C%s\u201D nemá žádný účinek na prvky jiné než 'A'

# not used by org.w3c.css.properties.CssSelectors for the moment
warning.noinside: \u201C%s\u201D nemůže být v lineárním prvku
warning.withblock: Pozor. Pseudo-prvky lze pouze připojit k úrovni prvku
warning.block-level: Tato vlastnost se vztahuje na úroveň prvku.

# used by org.w3c.css.parser.Frame
warning.no-declaration: Žádné prohlášení v pravidlu

# used by org.w3c.css.parser.CssFouffa
warning.unsupported-import: importované tabulky stylů nejsou zkontrolovány v režimech přímého vložení a nahrání souboru

# used by org.w3c.css.values.CssColor
warning.out-of-range: \u201C%s\u201D je mimo rozsah
error.invalid-color: neplatná funkce RGB

warning.marker: Vlastnost indexu se vztahuje na prvky s 'zobrazit:index'

# used by org.w3c.css.properties.ACssStyle
warning.relative: Použití relativních jednotek dává robustnější tabulky tylů ve vlastnosti \u201C%s\u201D

# used by org.w3c.css.css.StyleSheetParser and org.w3c.css.css.StyleSheetXMLParser
error.at-rule: Litujeme, pravidlo \u201C%s\u201D není implementováno.
warning.at-rule: Litujeme, pravidlo \u201C%s\u201D není implementováno.

# used by all properties and values
error.operator: \u201C%s\u201D je nesprávný operátor
error.negative-value: \u201C%s\u201D negativní hodnoty nejsou povoleny
error.few-value: příliš málo hodnot pro vlastnost \u201C%s\u201D

# pozor, nejprve hodnoty
# Nemůžete napsat něco jako toto: Pro barvu, modrá je nesprávná hodnota
error.value: \u201C%s\u201D není hodnota \u201C%s\u201D 

#used by org.w3c.css.properties3.CssToggleGroup
error.groupname: \u201C%s\u201D není správný název skupiny. Použijte platný identifikátor

#used by org.w3c.css.properties3.CssGroupReset
error.nogroup: \u201C%s\u201D nebylo nastaveno přepnutím vlastnosti

#used by org.w3c.css.properties3.CssGlyphOrVert
error.anglevalue: Hodnota musí být mezi -360 a 360 a  dělitelná 90

#used by org.w3c.css.properties3.CssTextKashidaSpace
error.percentage: očekávaná procentuální hodnota

#used by org.w3c.css.properties.CssTextAlign
warning.xsl: value \u201C%s\u201D se vztahuje pouze na XSL

#used by org.w3c.css.parser.analyzer.CssParser
warning.medialist: seznam médií by měl začínat 'médium :' \u201C%s\u201D
error.nocomb: Kombinační \u201C%s\u201D mezi selektory není v tomto profilu nebo verzi povoleno

#used by org.w3c.css.properties.CssDirection
warning.direction: místo použití 'směr' pro úroveň prvku použijte novou vlastnost CSS3 'režim psaní' 

# used by org.w3c.css.properties.CssTextDecoration
error.same-value: \u201C%s\u201D se zobrazuje dvakrát

error.generic-family.quote: Generické názvy jsou klíčová slova a tudíž nesmí být v uvozovkách.

# used by org.w3c.css.properties.CssClip
error.shape:Neplatná definice rect(<nahoru>,<doprava>,<dolů>,<doleva>)
error.shape-separator: Neplatné oddělení v definici. Musí to být čárka.

# used by org.w3c.css.properties.CssContent
error.attr: Neplatná definice atributu attr(X)
error.function: Neplatná definice funkce 
error.counter: Neplatná definice hloubky(<identifier>[,<list-style-type>]?)
error.counters: Neplatná definice hloubky (<identifier>,<string>[,<list-style-type>]?)

# used by org.w3c.css.font.Src
error.format: Neplatný formát definice formátu(<string>[,<string>]*)
error.local: Neplatný formát definice (<string>|<ident>+)

# used by org.w3c.css.values.CssAngle, org.w3c.css.values.CssFrequency, org.w3c.css.values.CssTime, org.w3c.css.values.CssLength
error.unit: \u201C%s\u201D je nesprávná jednotka.

# used by org.w3c.css.aural.ACssAzimuth
error.degree: Pozice musí být popsaná pomocí stupňů.

# used by org.w3c.css.aural.ACssElevation
error.elevation.range: Určuje vrchol jako úhel mezi '-90 stupni' a '90 stupni'.

# used by org.w3c.css.aural.ACssPitchRange
error.range: Hodnota je mimo rozsah. Tato hodnota musí být mezi '0' a '100'.

# used by org.w3c.css.properties.CssTextShadow
error.two-lengths: Vyrovnání stínu je specifikováno dvěma hodnotami <délky> (Poloměr rozostření může být stanoven po vyrovnání stínu.)

error.integer: Toto číslo by mělo být celé číslo
error.comma: Chybí čárka

# used by org.w3c.css.values.CssPercentage
error.percent: \u201C%s\u201D je nesprávné procento

# used by org.w3c.css.values.CssString
error.string: \u201C%s\u201D je nesprávný řetězec

# used by org.w3c.css.values.CssURL
error.url: \u201C%s\u201D je nesprávná URL

# used by org.w3c.css.values.CssColor
error.rgb: \u201C%s\u201D není platná barva 3 nebo 6 hexidecimálních čísel
error.angle: \u201C%s\u201D není platný úhel. Hodnota musí být mezi 0 a 360

# used by org.w3c.css.values.CssNumber
error.zero: pouze 0 může být \u201C%s\u201D. Musíte vložit jednotku za číslo
warning.zero: pouze 0 může být \u201C%s\u201D. Musíte vložit jednotku za číslo

#used by org.w3c.css.properties.CssColumnCount
error.strictly-positive: \u201C%s\u201D is not valid, only values greater than 0 allowed. <!-- translation unavailable -->

# used by org.w3c.css.parser.CssPropertyFactory
error.noexistence-at-all: Vlastnost \u201C%s\u201D neexistuje
error.noexistence-media: Vlastnost \u201C%s\u201D neexistuje pro média \u201C%s\u201D
error.noexistence: Vlastnost \u201C%s\u201D neexistuje v \u201C%s\u201D ale existuje v \u201C%s\u201D
warning.noexistence: Vlastnost  \u201C%s\u201D neexistuje v \u201C%s\u201D ale existuje v \u201C%s\u201D
warning.noexistence-media: Vlastnost  \u201C%s\u201D neexistuje pro média \u201C%s\u201D
warning.notforusermedium : Vlastnost \u201C%s\u201D neexistuje pro toto uživatelské médium
warning.noothermedium : Vlastnosti pro toto medium nemusí fungovat pro uživatelské médium
# used by org.w3c.css.parser.AtRule*
error.noatruleyet: Jiná @pravidla než @import nejsou CSS1 podporována \u201C%s\u201D
# used by org.w3c.css.parser.analyzer.CssParser
error.notforcss1: Hodnota \u201C%s\u201D pro CSS1 neexistuje
warning.pseudo: Neznámý pseudo-prvek nebo pseudo-třída \u201C%s\u201D v tomto profilu (\u201C%s\u201D)
warning.nocomb: Kombinator \u201C%s\u201D mezi voliči není v tomto profilu povolen (\u201C%s\u201D)
warning.charsetspecial: Tento profil má velice specifickou syntax pro @charset: @charset následuje přesně jeden prostor, po němž následuje název kódování v uvozovkách, které bezprostředně následuje středník.
warning.notversion: \u201C%s\u201D nelze použít s touto verzí CSS : \u201C%s\u201D

# used by org.w3c.css.parser.CssFouffa
error.unrecognize: Příliš mnoho hodnot nebo hodnoty, které nejsou rozpoznány.

# used by org.w3c.css.parser.CssFouffa
generator.unrecognize: Chyba při analýza
generator.dontmixhtml: Chyba při analýze. Styly by neměly obsahovat HTML syntaxe  

# used by org.w3c.css.css.StyleSheetGeneratorHTML2
error.unknown: Neznámá chyba

# used by org.w3c.css.parser.CssSelectors
error.pseudo-element: Pseudo-prvek :\u201C%s\u201D nemůže se zobrazit v kontextu \u201C%s\u201D
error.pseudo-class: Pseudo-třída .\u201C%s\u201D se nemůže zobrazit v HTML \u201C%s\u201D
error.pseudo: Neznámý pseudo-prvek nebo pseudo-třída \u201C%s\u201D
error.id: ID selector  #\u201C%s\u201D je neplatný! Pouze jeden ID selektor může být určen v jednoduchém selektoru: \u201C%s\u201D.
error.space: Pokud se atribut ~= používá, slovo v hodnotě \u201C%s\u201D nesmí obsahovat mezery.
error.todo : Omlouváme se, \u201C%s\u201D není dosud implementován.
error.incompatible: \u201C%s\u201D a \u201C%s\u201D jsou nekompatibilní
warning.incompatible: \u201C%s\u201D a \u201C%s\u201D jsou nekompatibilní
error.notformobile: \u201C%s\u201D nelze použít s mobilním profilem
error.notforatsc: \u201C%s\u201D nelze použít s ATSC profilem
error.notfortv: \u201C%s\u201D nelze použít s TV profilem
error.notversion: \u201C%s\u201D nelze použít s verzí CSS : \u201C%s\u201D

error.media: nerozpoznané médium \u201C%s\u201D 
error.page: nerozpoznaná pseudo-pojmenovaná stránka \u201C%s\u201D

error.unrecognized.link: Nerozpoznaný prvek odkazu nebo tabulky stylů xml PI.

# používáno StyleSheetGeneratorHTML
generator.context: Kontext
generator.request: Při vkládání došlo k chybě. Opravte svůj požadavek nebo zašlete e-mail na www-validator-css@w3.org.
generator.unrecognized: Nerozpoznaný
generator.invalid-number: Neplatné číslo
generator.property: Chyba
generator.line: Řádek
generator.not-found: Soubor nenalezen

generator.doc-html:   <!—tento zavádějící vzkaz odstraněn olivier 2006-12-14 -->
generator.doc:  <!-- tento zavádějící vzkaz odstraněn olivier 2006-12-14 -->


# used by the parser
parser.semi-colon: pokuste se najít před názvem vlastnosti dvojtečku. přidejte ji

parser.unknown-dimension: Neznámý rozměr

parser.old_class: V CSS1 by měl název třídy začínat číslicí  (".55ft"), pokud nejde o rozměr (".55in"). V CSS2 jsou takové třídy odděleny jako neznámé rozměry (aby bylo možné budoucí doplnění nových jednotek) Abyste  z".\u201C%s\u201D" vytvořili platnou třídu, CSS2 vyžaduje aby byla první číslice vynechaná ".\3\u201C%s\u201D"

parser.old_id: V CSS1 může id začínat číslicí  ("#55ft"), pokud nejde o rozměr ("#55in"). V CSS2 jsou taková id oddělena jako neznámé rozměry (aby bylo možné budoucí doplnění nových jednotek).

parser.class_dim:V CSS1 může název třídy začínat číslicí (".55ft"), pokud nejde o rozměr (".55in").

parser.id_dim: V CSS1 může název začínat číslicí ("#55ft"), pokud nejde o rozměr ("#55in").

parser.charset: Pravidlo @charset lze provést pouze na začátku listu. Zkontrolujte, že před ním nejsou žádné mezery.

parser.charsetspecial: Tento profil má velmi specifickou syntax pro @charset: @charset následuje přesně jedna mezera, po níž následuje název kódování v uvozovkách, po kterých bezprostředně následuje středník.

warning.old_id: V CSS1 může název začínat číslicí ("#55ft"), pokud  nejde o rozměr ("#55in"). V CSS2 jsou taková id chápaná jako neznámé rozměry (k možnému budoucímu doplnění nových jednotek)

warning.old_class: V CSS1 může název třídy začínat číslicí ("#55ft"), pokud nejde o rozměr ("#55in"). V CSS2 jsou taková id chápaná jako neznámé rozměry (k možnému budoucímu doplnění nových jednotek).

# used by the servlet
servlet.invalid-request: Odeslali jste neplatnou žádost.
servlet.process: Nemůže zpracovat objekt

warning.atsc: \u201C%s\u201D nemusí být  podporována médiem atsc-tv
error.onlyATSC: \u201C%s\u201D tato funkce je pouze pro medium  atsc-tv

warning.otherprofile: Pro tento profil neexistuje vlastnost \u201C%s\u201D, ale je ověřena v souladu s  jiným profilem.

warning.float-no-width: V (x)HTML+CSS, plovoucí prvky musí mít otevřenou šířku. Netýká se to pouze prvků s vnitřní šířkou (html, img, input, textarea, select nebo object)

parser.charsetcss1: pravidla @charset nelze použít v CSS1
parser.attrcss1: Selektory s atributem jsou v CSS1 neplatné

warning.noexproperty: Vlastnost \u201C%s\u201D neexistuje
error.divisortype: Dělitel musí být číslo
error.greater: \u201C%s\u201D není validní, povoleny jsou pouze hodnoty striktně větší než \u201C%s\u201D.
error.bg_order: V CSS3 background definici se v případě výskytu obou vlastností musí 'bg_position' nacházet před / 'bg_size'

